@@ -1,27 +1,16 @@
 //
-// Copyright 2014 Ettus Research LLC
+// Copyright 2014-2016 Ettus Research LLC
+// Copyright 2018 Ettus Research, a National Instruments Company
 //
-// This program is free software: you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// SPDX-License-Identifier: GPL-3.0-or-later
 //
 
 #ifndef INCLUDED_UHD_TYPES_SID_HPP
 #define INCLUDED_UHD_TYPES_SID_HPP
 
 #include <uhd/config.hpp>
-#include <stdint.h>
-#include <boost/shared_ptr.hpp>
 #include <iostream>
+#include <stdint.h>
 
 namespace uhd {
     /*!
@@ -40,7 +29,13 @@ namespace uhd {
      * is required, we use the combination of the 8-bit address and the 8-bit
      * endpoint.
      *
-     * \section sid_str_repr String Representation
+     * <pre>
+     * +-------------+--------------+-------------+--------------+
+     * | SRC address | SRC endpoint | DST address | DST endpoint |
+     * +-------------+--------------+-------------+--------------+
+     * </pre>
+     *
+     * \section sid_str_repr String Representation (pretty printing)
      *
      * The string representation of a SID is of the form
      *
@@ -99,47 +94,47 @@ namespace uhd {
         // Getters
         //
         //! Alias for get_sid()
-        UHD_INLINE uint32_t get() const { return get_sid(); };
+        inline uint32_t get() const { return get_sid(); };
         //! Returns a 32-Bit representation of the SID if set, or zero otherwise.
-        UHD_INLINE uint32_t get_sid() const { return _set ? _sid : 0; };
+        inline uint32_t get_sid() const { return _set ? _sid : 0; };
         //! Return the 16-bit source address of this SID
-        UHD_INLINE uint32_t get_src() const {
+        inline uint32_t get_src() const {
             return (_sid >> 16) & 0xFFFF;
         }
         //! Return the 16-bit destination address of this SID
-        UHD_INLINE uint32_t get_dst() const {
+        inline uint32_t get_dst() const {
             return _sid & 0xFFFF;
         }
         //! Return 8-bit address of the source
-        UHD_INLINE uint32_t get_src_addr() const {
+        inline uint32_t get_src_addr() const {
             return (get_src() >> 8) & 0xFF;
         }
         //! Return endpoint of the source
-        UHD_INLINE uint32_t get_src_endpoint() const {
+        inline uint32_t get_src_endpoint() const {
             return get_src() & 0xFF;
         }
         //! Return crossbar port of the source
-        UHD_INLINE uint32_t get_src_xbarport() const {
+        inline uint32_t get_src_xbarport() const {
             return (get_src_endpoint() >> 4) & 0xF;
         }
         //! Return block port of the source
-        UHD_INLINE uint32_t get_src_blockport() const {
+        inline uint32_t get_src_blockport() const {
             return (get_src_endpoint()) & 0xF;
         }
         //! Return 8-bit address of the destination
-        UHD_INLINE uint32_t get_dst_addr() const {
+        inline uint32_t get_dst_addr() const {
             return (get_dst() >> 8) & 0xFF;
         }
         //! Return endpoint of the destination
-        UHD_INLINE uint32_t get_dst_endpoint() const {
+        inline uint32_t get_dst_endpoint() const {
             return get_dst() & 0xFF;
         }
         //! Return crossbar port of the source
-        UHD_INLINE uint32_t get_dst_xbarport() const {
+        inline uint32_t get_dst_xbarport() const {
             return (get_dst_endpoint() >> 4) & 0xF;
         }
         //! Return block port of the source
-        UHD_INLINE uint32_t get_dst_blockport() const {
+        inline uint32_t get_dst_blockport() const {
             return (get_dst_endpoint()) & 0xF;
         }
 
@@ -168,14 +163,14 @@ namespace uhd {
         // Manipulators
 
         //! Swaps dst and src address and returns the new SID.
-        sid_t reversed();
+        sid_t reversed() const;
 
-        //! Swaps dst and src in-place.
+        //! Swaps dst and src in-place. This modifies the current SID.
         void reverse();
 
         // Overloaded operators
 
-        sid_t operator = (uint32_t new_sid) {
+        sid_t operator = (const uint32_t new_sid) {
             set_sid(new_sid);
             return *this;
         }
@@ -185,6 +180,11 @@ namespace uhd {
             return *this;
         }
 
+        sid_t operator = (const sid_t &sid) {
+            set_sid(sid.get_sid());
+            return *this;
+        }
+
         sid_t operator = (const std::string &sid_str) {
             set_from_str(sid_str);
             return *this;
@@ -222,7 +222,7 @@ namespace uhd {
     };
 
     //! Stream output operator. Honors std::ios::hex.
-    UHD_INLINE std::ostream& operator<< (std::ostream& out, const sid_t &sid) {
+    inline std::ostream& operator<< (std::ostream& out, const sid_t &sid) {
         std::ios_base::fmtflags ff = out.flags();
         if (ff & std::ios::hex) {
             out << sid.to_pp_string_hex();
